@@ -1,22 +1,23 @@
 /* util.h 
    Copyright (C) 2000 Werner Koch (dd9jn)
-   Copyright (C) 2001, 2002, 2003 g10 Code GmbH
+   Copyright (C) 2001, 2002, 2003, 2004 g10 Code GmbH
 
    This file is part of GPGME.
  
    GPGME is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
- 
+   under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of
+   the License, or (at your option) any later version.
+   
    GPGME is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
- 
-   You should have received a copy of the GNU General Public License
-   along with GPGME; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Lesser General Public License for more details.
+   
+   You should have received a copy of the GNU Lesser General Public
+   License along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #ifndef UTIL_H
 #define UTIL_H
@@ -44,27 +45,17 @@ int vasprintf (char **result, const char *format, va_list args);
 int asprintf (char **result, const char *format, ...);
 #endif
 
-#if !HAVE_FOPENCOOKIE
-#include <fcntl.h> /* make sure that ssize_t and off_t are defined */
-typedef struct
-{
-  ssize_t (*read)(void*,char*,size_t);
-  ssize_t (*write)(void*,const char*,size_t);
-  int (*seek)(void*,off_t*,int);
-  int (*close)(void*);
-} _IO_cookie_io_functions_t;
-typedef _IO_cookie_io_functions_t cookie_io_functions_t;
-FILE *fopencookie (void *cookie, const char *opentype,
-                   cookie_io_functions_t funclist);
-#endif /*!HAVE_FOPENCOOKIE*/
-#endif /*HAVE_CONFIG_H*/
+#ifndef HAVE_TTYNAME_R
+int ttyname_r (int fd, char *buf, size_t buflen);
+#endif
+#endif
 
 
 /*-- conversion.c --*/
 /* Convert two hexadecimal digits from STR to the value they
    represent.  Returns -1 if one of the characters is not a
    hexadecimal digit.  */
-int _gpgme_hextobyte (const unsigned char *str);
+int _gpgme_hextobyte (const char *str);
 
 /* Decode the C formatted string SRC and store the result in the
    buffer *DESTP which is LEN bytes long.  If LEN is zero, then a
@@ -72,7 +63,8 @@ int _gpgme_hextobyte (const unsigned char *str);
    the result.  Currently, LEN is only used to specify if allocation
    is desired or not, the caller is expected to make sure that *DESTP
    is large enough if LEN is not zero.  */
-gpgme_error_t _gpgme_decode_c_string (const char *src, char **destp, int len);
+gpgme_error_t _gpgme_decode_c_string (const char *src, char **destp,
+				      size_t len);
 
 /* Decode the percent escaped string SRC and store the result in the
    buffer *DESTP which is LEN bytes long.  If LEN is zero, then a
@@ -81,8 +73,23 @@ gpgme_error_t _gpgme_decode_c_string (const char *src, char **destp, int len);
    is desired or not, the caller is expected to make sure that *DESTP
    is large enough if LEN is not zero.  */
 gpgme_error_t _gpgme_decode_percent_string (const char *src, char **destp,
-					 int len);
+					    size_t len);
+
+
+/* Parse the string TIMESTAMP into a time_t.  The string may either be
+   seconds since Epoch or in the ISO 8601 format like
+   "20390815T143012".  Returns 0 for an empty string or seconds since
+   Epoch. Leading spaces are skipped. If ENDP is not NULL, it will
+   point to the next non-parsed character in TIMESTRING. */
+time_t _gpgme_parse_timestamp (const char *timestamp, char **endp);
+
 
 gpgme_error_t _gpgme_map_gnupg_error (char *err);
 
+
+/* Retrieve the environment variable NAME and return a copy of it in a
+   malloc()'ed buffer in *VALUE.  If the environment variable is not
+   set, return NULL in *VALUE.  */
+gpgme_error_t _gpgme_getenv (const char *name, char **value);
+
 #endif /* UTIL_H */
